.. _contributing-md-file:

``CONTRIBUTING.md`` file
========================

This file contains instructions about how to contribute to your charm. It can contain
anything you want, but it is recommended that it have at least:

- How to set up a development environment
- Code and test standards
- Instructions for submitting changes upstream.
